@@ -5,7 +5,7 @@ store <- local({
 	if(missing(value)) return(refList[[name]])
 	refList[name] <<- list(value)
     }
-  })
+})
 
 # , envir=as.environment(which(search()=='package:vegdata'))
 # store <- local({
@@ -70,20 +70,21 @@ concept.FUN <- function(species, concept, ...) {
 }
 # Subsetting
 select.taxa <- function(x, species, strict) {
-   if(is.numeric(x) | is.integer(x))   l <- species[match(x, species$SPECIES_NR),]
-   if(is.character(x)) {
-    x <- sub.abbr(x)
-    x <- unique(unlist(strsplit(x, ".", fixed = TRUE)))
-    if(nchar(x[1]) == 7 & x[1] == toupper(x[1]))  {
+  if(is.factor(x)) x <- as.character(x)
+  if(is.numeric(x) | is.integer(x))  
+	l <- species[match(x, species$SPECIES_NR),]  ## Tax numbers
+  if(is.character(x)) {
+#    x <- sub.abbr(x)
+#   x <- unique(unlist(strsplit(x, ".", fixed = TRUE))) # Pseudo-Species
+    if(nchar(x[1]) == 7 & x[1] == toupper(x[1]))  {	## Lettercode
 	l <- species[species$LETTERCODE %in% x,] 
-# 	if(syn == FALSE & !is.numeric(x)) l <- l[l$SYNONYM == FALSE,]
-	} else {
-	l <- character()
-	for(i in 1:length(x)) 
-	l <- if(!strict) c(l, species[grep(x[i], species$ABBREVIAT, useBytes=TRUE), 'ABBREVIAT']) else c(l, species$ABBREVIAT[species$ABBREVIAT == x[i]])
-        l <- species[match(l, species$ABBREVIAT),]
+	} else {		## Taxnames
+	l <- species[species$SPECIES_NR==(-1),]
+	for(i in 1:length(x))
+	  l <- if(!strict) rbind(l, species[grep(x[i], species$ABBREVIAT, useBytes=TRUE), ]) else 
+			   rbind(l, species[match(species$ABBREVIAT, x[i], nomatch = 0) > 0, ])
       }
-    }
+   }
    if(length(l) == 0) stop('No species found!')
    return(l)
 }
@@ -104,6 +105,8 @@ if(is.null(store(reflist))) { # load.species(refl=refl, verbose = verbose)
     } else cat('\nTaxonomic evaluation list (',dbf, ') of ', refl, 'not available.\n')
   }
   species <- read.dbf(file.path(tv_home, 'Species', refl, dbf))
+  for(i in which(sapply(species, is.factor))) species[,i] <- as.character(species[,i]) # ob nötig?
+  for(i in which(sapply(species, is.character))) Encoding(species[,i]) <- 'latin1' # ob nötig?
   species$ABBREVIAT <- sub.abbr(species$ABBREVIAT)
   if(verbose) species$VALID_NAME <- sub.abbr(species$VALID_NAME)
   store(reflist, species)
@@ -113,8 +116,6 @@ if(is.null(store(reflist))) { # load.species(refl=refl, verbose = verbose)
   }
 
 # Filter
-for(i in which(sapply(species, is.factor))) species[,i] <- as.character(species[,i])
-for(i in which(sapply(species, is.character))) Encoding(species[,i]) <- 'latin1'
 if(!is.null(concept)) species <- concept.FUN(species, concept)
 if(x[1] != 'all') species <- select.taxa(x, species, strict)
 if(!syn) species <- species[species$SYNONYM == FALSE,]
@@ -127,35 +128,41 @@ return(species)
 #  ls(pos='package:vegdata')
 
 
-childs <- function (x, refl, species, gen=5, tree=FALSE, quiet=FALSE, ...) {
+childs <- function (x, refl, species, gen=4, tree=FALSE, quiet=FALSE, ...) {
  if(missing(species)) species <- tax("all", verbose = TRUE, refl = refl, syn = FALSE)
-  x <- tax(x, refl=refl, strict=TRUE, syn = FALSE)$SPECIES_NR
-#  if(length(x)>1) warning('More than one match, using only first.')
+ if(length(x)>1) warning('More than one species selected, using only the first.')
   x <- x[1]
-  if(tree==TRUE) {
+  if(is.character(x)) x <- species[match(x, species$ABBREVIAT),'SPECIES_NR']
+#    x <- tax(x, refl=tv.refl(refl), strict=TRUE, syn = FALSE)$SPECIES_NR	# too many ressources used
+
+  if(tree) {
     require(gWidgets)
     root <- childs(x, gen=1)
     offspring <- function(path, ...) {
-    ll <- root
-    for(i in path)
-	ll <- childs(i, gen=1, quiet=TRUE)
-	out <- data.frame(Name=ll$ABBREVIAT,
-                    hasOffspring=!is.null(childs(ll$SPECIES_NR, quiet=TRUE)),
-                    Rang=ll$RANG,
-#                     Edit=ll$EDITSTATUS,
-                    Nr=ll$SPECIES_NR,
-                   stringsAsFactors=FALSE)
-    out	}
+      ll <- root
+      for(i in path)
+	  ll <- childs(i, gen=1, tree=FALSE, quiet=TRUE)
+	  out <- data.frame(Name=ll$ABBREVIAT,
+		      hasOffspring=!is.null(childs(ll$SPECIES_NR, quiet=TRUE)),
+		      Rang=ll$RANG,
+		      Nr=ll$SPECIES_NR,
+		    stringsAsFactors=FALSE)
+      out
+    }
     w <- gwindow(paste("Taxonomic Tree of", species$ABBREVIAT[species$SPECIES_NR==x]))
     tr <- gtree(offspring=offspring, container=w)  
     addHandlerDoubleclick(tr, handler=function(h,...) {
       print(childs(svalue(h$obj), gen=1)[,c('SPECIES_NR','LETTERCODE','ABBREVIAT','GRUPPE','RANG','AGG','SECUNDUM','EDITSTATUS')])
       })
   } else {
- x <- species[match(x, species$SPECIES_NR),'VALID_NR']
- x <- species[match(x, species$SPECIES_NR),]
- Agg <- species[which(species$AGG == x$SPECIES_NR),]
-  if(nrow(Agg)==0) {if(!quiet) cat(x$ABBREVIAT, 'has no childs.\n') } else {
+    x <- species[match(x, species$SPECIES_NR),'VALID_NR']
+    x <- species[match(x, species$SPECIES_NR),]
+    Agg <- species[which(species$AGG == x$SPECIES_NR),]
+    if(nrow(Agg)==0) {
+    if(!quiet) cat(x$ABBREVIAT, 'has no childs.\n') 
+  } else 
+  {
+
     Agg$GENERATION <- 1
     ag2 <- Agg
     t <- 1
